==> pvfs-kernel-1.5.8-linux-2.4.tgz: pvfs-kernel-1.5.8-linux-2.4/kpvfsd.h <==
#ifndef __KPVFSD_H
#define __KPVFSD_H

/*
 * pvfsd.h copyright (c) 1999 Rob Ross and Phil Carns, all rights reserved.
 *
 * Written by Rob Ross and Phil Carns.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross   rbross@parl.clemson.edu
 *           Phil Carns pcarns@parl.clemson.edu
 */


/* arguments to the pvfsd kernel thread(s) */

struct kpvfsd_args {
		  /* these fields need to be initialized by init_module(i.e. insmod)
			  and passed to pvfsd */
		  int pa_id;
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
		  wait_queue_head_t pa_queue;
#else
		  struct wait_queue *pa_queue;
#endif
		  pvfs_boolean_t pa_stop;
		  /* use this semaphore to synchronize the start and stop of all pvfsd  threads */
		  struct semaphore pa_start_stop;
#if defined(NEW_STYLE_KPVFSD) && LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
		  struct tq_struct  tq;
		  int (*function)(struct kpvfsd_args *);
#endif
		  /* these fields will be setup by the pvfsd kernel thread possibly used by cleanup_module() */
		  struct task_struct *pa_thread;
		  int pa_exit_code;
};

typedef enum {false = 0, true = 1} bool;
extern struct kpvfsd_args *thread_args;
extern int num_kpvfsd_threads, pvfs_debug;
extern int init_kpvfsd(void);
extern int cleanup_kpvfsd(int num_threads);
extern int kpvfsd(struct kpvfsd_args *);
extern int check_for_signal_to_kpvfsd(void);

#endif

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 *
 * vim: ts=3
 * End:
 */

==> pvfs-kernel-1.6.3-linux-2.4.tgz: pvfs-kernel-1.6.3-linux-2.4/kpvfsd.h <==
#ifndef __KPVFSD_H
#define __KPVFSD_H

/*
 * pvfsd.h copyright (c) 1999 Rob Ross and Phil Carns, all rights reserved.
 *
 * Written by Rob Ross and Phil Carns.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross   rbross@parl.clemson.edu
 *           Phil Carns pcarns@parl.clemson.edu
 */


/* arguments to the pvfsd kernel thread(s) */

struct kpvfsd_args {
		  /* these fields need to be initialized by init_module(i.e. insmod)
			  and passed to pvfsd */
		  int pa_id;
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
		  wait_queue_head_t pa_queue;
#else
		  struct wait_queue *pa_queue;
#endif
		  pvfs_boolean_t pa_stop;
		  /* use this semaphore to synchronize the start and stop of all pvfsd  threads */
		  struct semaphore pa_start_stop;
#if defined(NEW_STYLE_KPVFSD) && LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
		  struct tq_struct  tq;
		  int (*function)(struct kpvfsd_args *);
#endif
		  /* these fields will be setup by the pvfsd kernel thread possibly used by cleanup_module() */
		  struct task_struct *pa_thread;
		  int pa_exit_code;
};

typedef enum {false = 0, true = 1} bool;
extern struct kpvfsd_args *thread_args;
extern int num_kpvfsd_threads, pvfs_debug;
extern int init_kpvfsd(void);
extern int cleanup_kpvfsd(int num_threads);
extern int kpvfsd(struct kpvfsd_args *);
extern int check_for_signal(int *sig_nr);

#endif

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 *
 * vim: ts=3
 * End:
 */
